@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002, 2009 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002, 2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,9 +12,9 @@
 #
 ##############################################################################
 """Component Architecture Tests
-
-$Id: tests.py 109656 2010-03-04 19:49:14Z kobold $
 """
+
+import doctest
 import persistent
 import re
 import sys
@@ -25,8 +25,8 @@ from cStringIO import StringIO
 from zope import interface, component
 from zope.interface.verify import verifyObject
 from zope.interface.interfaces import IInterface
-from zope.testing import doctest, renormalizing
-from zope.testing.testrunner.layer import UnitTests
+from zope.testing import renormalizing
+from zope.testrunner.layer import UnitTests
 
 from zope.component.interfaces import ComponentLookupError
 from zope.component.interfaces import IComponentArchitecture
@@ -1729,6 +1729,8 @@ def test_suite():
         doctest.DocTestSuite('zope.component.security'),
         doctest.DocFileSuite('zcml.txt', checker=checker,
                              setUp=setUp, tearDown=tearDown),
+        doctest.DocFileSuite('configure.txt',
+                             setUp=setUp, tearDown=tearDown),
         doctest.DocFileSuite('testlayer.txt',
                              optionflags=(doctest.ELLIPSIS +
                                           doctest.NORMALIZE_WHITESPACE +
